==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/appmesh_mesh/AppmeshMeshSpec.java <==
package com.hashicorp.cdktf.providers.aws.appmesh_mesh;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:51.498Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.appmeshMesh.AppmeshMeshSpec")
@software.amazon.jsii.Jsii.Proxy(AppmeshMeshSpec.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface AppmeshMeshSpec extends software.amazon.jsii.JsiiSerializable {

    /**
     * egress_filter block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/appmesh_mesh#egress_filter AppmeshMesh#egress_filter}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.appmesh_mesh.AppmeshMeshSpecEgressFilter getEgressFilter() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AppmeshMeshSpec}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AppmeshMeshSpec}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<AppmeshMeshSpec> {
        com.hashicorp.cdktf.providers.aws.appmesh_mesh.AppmeshMeshSpecEgressFilter egressFilter;

        /**
         * Sets the value of {@link AppmeshMeshSpec#getEgressFilter}
         * @param egressFilter egress_filter block.
         *                     Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/appmesh_mesh#egress_filter AppmeshMesh#egress_filter}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder egressFilter(com.hashicorp.cdktf.providers.aws.appmesh_mesh.AppmeshMeshSpecEgressFilter egressFilter) {
            this.egressFilter = egressFilter;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AppmeshMeshSpec}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public AppmeshMeshSpec build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link AppmeshMeshSpec}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AppmeshMeshSpec {
        private final com.hashicorp.cdktf.providers.aws.appmesh_mesh.AppmeshMeshSpecEgressFilter egressFilter;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.egressFilter = software.amazon.jsii.Kernel.get(this, "egressFilter", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.appmesh_mesh.AppmeshMeshSpecEgressFilter.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.egressFilter = builder.egressFilter;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.appmesh_mesh.AppmeshMeshSpecEgressFilter getEgressFilter() {
            return this.egressFilter;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getEgressFilter() != null) {
                data.set("egressFilter", om.valueToTree(this.getEgressFilter()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.appmeshMesh.AppmeshMeshSpec"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AppmeshMeshSpec.Jsii$Proxy that = (AppmeshMeshSpec.Jsii$Proxy) o;

            return this.egressFilter != null ? this.egressFilter.equals(that.egressFilter) : that.egressFilter == null;
        }

        @Override
        public final int hashCode() {
            int result = this.egressFilter != null ? this.egressFilter.hashCode() : 0;
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/appmesh_mesh/AppmeshMeshSpec.java <==
package com.hashicorp.cdktf.providers.aws.appmesh_mesh;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:07.296Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.appmeshMesh.AppmeshMeshSpec")
@software.amazon.jsii.Jsii.Proxy(AppmeshMeshSpec.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface AppmeshMeshSpec extends software.amazon.jsii.JsiiSerializable {

    /**
     * egress_filter block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/appmesh_mesh#egress_filter AppmeshMesh#egress_filter}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.appmesh_mesh.AppmeshMeshSpecEgressFilter getEgressFilter() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AppmeshMeshSpec}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AppmeshMeshSpec}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<AppmeshMeshSpec> {
        com.hashicorp.cdktf.providers.aws.appmesh_mesh.AppmeshMeshSpecEgressFilter egressFilter;

        /**
         * Sets the value of {@link AppmeshMeshSpec#getEgressFilter}
         * @param egressFilter egress_filter block.
         *                     Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/appmesh_mesh#egress_filter AppmeshMesh#egress_filter}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder egressFilter(com.hashicorp.cdktf.providers.aws.appmesh_mesh.AppmeshMeshSpecEgressFilter egressFilter) {
            this.egressFilter = egressFilter;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AppmeshMeshSpec}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public AppmeshMeshSpec build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link AppmeshMeshSpec}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AppmeshMeshSpec {
        private final com.hashicorp.cdktf.providers.aws.appmesh_mesh.AppmeshMeshSpecEgressFilter egressFilter;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.egressFilter = software.amazon.jsii.Kernel.get(this, "egressFilter", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.appmesh_mesh.AppmeshMeshSpecEgressFilter.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.egressFilter = builder.egressFilter;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.appmesh_mesh.AppmeshMeshSpecEgressFilter getEgressFilter() {
            return this.egressFilter;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getEgressFilter() != null) {
                data.set("egressFilter", om.valueToTree(this.getEgressFilter()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.appmeshMesh.AppmeshMeshSpec"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AppmeshMeshSpec.Jsii$Proxy that = (AppmeshMeshSpec.Jsii$Proxy) o;

            return this.egressFilter != null ? this.egressFilter.equals(that.egressFilter) : that.egressFilter == null;
        }

        @Override
        public final int hashCode() {
            int result = this.egressFilter != null ? this.egressFilter.hashCode() : 0;
            return result;
        }
    }
}
